@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-10-04'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -152,7 +152,6 @@ sub munge_files {
         $distmodules{$mod}++;
     }
 
-    my %seen_mods;
     for my $file (@{ $self->found_files }) {
         next unless $file->name =~ m!\Alib/(Bencher/Scenario/.+)\.pm\z!;
 
@@ -163,11 +162,10 @@ sub munge_files {
         my @modules = Bencher::Backend::_get_participant_modules($scenario);
         for my $mod (@modules) {
             next if $distmodules{$mod};
-            next if $seen_mods{$mod}++;
             my $ver = $scenario->{modules}{$mod}{version} // 0;
             $self->log_debug(
-                ["Adding prereq to benchmarked module %s (version %s)",
-                 $mod, $ver]);
+                ["(scenario %s) Adding prereq to benchmarked module %s (version %s)",
+                 $pkg, $mod, $ver]);
             $self->zilla->register_prereqs(
                 {phase=>'runtime', type=>'requires'}, $mod, $ver);
         }
@@ -225,7 +223,7 @@ Dist::Zilla::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.13 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-07-13.
+This document describes version 0.14 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-10-04.
 
 =head1 SYNOPSIS
 
